@@ -15,12 +15,14 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+location=$(dirname $0)
+
 deploy_crd_file() {
   source=$1
   # Make a copy to serve as the base for post-processing
   cp "$source" "${source}.orig"
   # Post-process source
-  cat ./header.txt > "$source"
+  cat $location/header.txt > "$source"
   echo "" >> "$source"
   cat ${source}.orig >> "$source"
 
@@ -32,7 +34,7 @@ deploy_crd_file() {
   rm -f "${source}.orig"
 }
 
-go install sigs.k8s.io/controller-tools/cmd/controller-gen@v0.15.0
+go install sigs.k8s.io/controller-tools/cmd/controller-gen@v0.17.2
 $(go env GOPATH)/bin/controller-gen object paths=./...
 $(go env GOPATH)/bin/controller-gen crd paths=./...
 # Let's also run some test to validate the project
